@@ -32,6 +32,7 @@ group :test do
 	gem "decode"
 	
 	gem "rubocop"
+	gem "rubocop-md"
 	gem "rubocop-socketry"
 	
 	gem "sus-fixtures-async"
@@ -44,4 +45,5 @@ group :test do
 	gem "bake-test-external"
 	
 	gem "benchmark-ips"
+	gem "openssl", "~> 3.3.2"
 end
