@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2017-2022, by Samuel Williams.
+# Copyright, 2017-2025, by Samuel Williams.
 # Copyright, 2020, by Salim Semaoune.
 
 require_relative "async/version"
@@ -9,6 +9,8 @@ require_relative "async/reactor"
 
 require_relative "kernel/async"
 require_relative "kernel/sync"
+require_relative "kernel/barrier"
 
+# Asynchronous programming framework.
 module Async
 end
