@@ -9,6 +9,7 @@
 require_relative "clock"
 require_relative "task"
 require_relative "timeout"
+require_relative "fork_handler"
 
 require "io/event"
 
@@ -45,7 +46,7 @@ module Async
 		def self.supported?
 			true
 		end
-
+		
 		# Used to augment the scheduler to add support for blocking operations.
 		module BlockingOperationWait
 			# Wait for the given work to be executed.
@@ -59,7 +60,7 @@ module Async
 				@worker_pool.call(work)
 			end
 		end
-
+		
 		private_constant :BlockingOperationWait
 		
 		if ::IO::Event.const_defined?(:WorkerPool)
@@ -67,7 +68,7 @@ module Async
 		else
 			WorkerPool = nil
 		end
-
+		
 		# Create a new scheduler.
 		#
 		# @public Since *Async v1*.
@@ -93,7 +94,7 @@ module Async
 			else
 				@worker_pool = worker_pool
 			end
-
+			
 			if @worker_pool
 				self.singleton_class.prepend(BlockingOperationWait)
 			end
@@ -120,7 +121,7 @@ module Async
 				return @busy_time / total_time
 			end
 		end
-	
+		
 		# Invoked when the fiber scheduler is being closed.
 		#
 		# Executes the run loop until all tasks are finished, then closes the scheduler.
@@ -146,24 +147,26 @@ module Async
 		# Terminate all child tasks and close the scheduler.
 		# @public Since *Async v1*.
 		def close
-			self.run_loop do
-				until self.terminate
-					self.run_once!
+			unless @children.nil?
+				self.run_loop do
+					until self.terminate
+						self.run_once!
+					end
 				end
 			end
 			
 			Kernel.raise "Closing scheduler with blocked operations!" if @blocked > 0
 		ensure
 			# We want `@selector = nil` to be a visible side effect from this point forward, specifically in `#interrupt` and `#unblock`. If the selector is closed, then we don't want to push any fibers to it.
-			selector = @selector
-			@selector = nil
+			if selector = @selector
+				@selector = nil
+				selector.close
+			end
 			
-			selector&.close
-			
-			worker_pool = @worker_pool
-			@worker_pool = nil
-			
-			worker_pool&.close
+			if worker_pool = @worker_pool
+				@worker_pool = nil
+				worker_pool.close
+			end
 			
 			consume
 		end
@@ -583,7 +586,8 @@ module Async
 		# @yields {|task| ...} Executed within the task.
 		# @returns [Task] The task that was scheduled into the reactor.
 		def async(*arguments, **options, &block)
-			warn("Async::Scheduler#async is deprecated. Use `run` or `Task#async` instead.", uplevel: 1, category: :deprecated) if $VERBOSE
+			# Since this method is called by `run`, this warning is too excessive:
+			# warn("Async::Scheduler#async is deprecated. Use `run` or `Task#async` instead.", uplevel: 1, category: :deprecated) if $VERBOSE
 			
 			Kernel.raise ClosedError if @selector.nil?
 			
@@ -641,5 +645,24 @@ module Async
 				yield duration
 			end
 		end
+		
+		# Handle fork in the child process. This method is called automatically when `Process.fork` is invoked.
+		#
+		# The child process starts with a clean slate - no scheduler is set. Users can create a new scheduler if needed.
+		#
+		# @public Since *Async v2.35*.
+		def process_fork
+			if profiler = @profiler
+				@profiler = nil
+				profiler.stop
+			end
+			
+			@children = nil
+			@selector = nil
+			@timers = nil
+			
+			# Close the scheduler:
+			Fiber.set_scheduler(nil)
+		end
 	end
 end
