@@ -21,9 +21,10 @@ describe Async::Condition do
 		
 		expect(task).to be(:running?)
 		
-		# This will cause the task to exit:
 		condition.signal
 		
+		task.wait
+		
 		expect(task).to be(:completed?)
 	end
 	
