@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2024, by Samuel Williams.
+# Copyright, 2020-2025, by Samuel Williams.
 
 require "sus/fixtures/async"
 require "async/reactor"
@@ -11,7 +11,7 @@ require "net/http"
 require "sus/fixtures/console"
 
 describe Async::Scheduler do
-	include_context Sus::Fixtures::Console::CapturedLogger
+	include Sus::Fixtures::Console::CapturedLogger
 	
 	it "is supported" do
 		expect(Async::Scheduler).to be(:supported?)
